@@ -1,6 +1,8 @@
-
 def eq(code, **kwargs):
 	from matplotlib.figure import Figure
+	import matplotlib.pyplot as plt
+	plt.rc('text', usetex=True)
+	plt.rc('font', family='serif')
 	if "horizontalalignment" not in kwargs:
 		kwargs["horizontalalignment"] = "center"
 	if "verticalalignment" not in kwargs:
