@@ -105,6 +105,7 @@ class FileActions(Actions):
             "pys": Pys,
             "pysu": Pys,
             "xls": Xls,
+            "xlsx": Xls,
         }
 
     def _is_aborted(self, cycle, statustext, total_elements=None, freq=None):
@@ -171,14 +172,15 @@ class FileActions(Actions):
         sigfilename = filename + '.sig'
 
         try:
-            dummy = open(sigfilename)
-            dummy.close()
+            with open(sigfilename):
+                pass
+
         except IOError:
             # Signature file does not exist
             return False
 
         # Check if the sig is valid for the sigfile
-        # TODO: Check for whitespace in filenpaths
+        # TODO: Check for whitespace in filepaths
         return verify(sigfilename, filename)
 
     def enter_safe_mode(self):
@@ -317,7 +319,7 @@ class FileActions(Actions):
             except:
                 file_ext = None
 
-            if file_ext in ["pys", "pysu"]:
+            if file_ext in ["pys", "pysu", "xls", "xlsx"]:
                 filetype = file_ext
             else:
                 filetype = "pys"
@@ -332,6 +334,9 @@ class FileActions(Actions):
             type2opener["xls"] = \
                 (xlrd.open_workbook, [filepath], {"formatting_info": True})
 
+            type2opener["xlsx"] = \
+                (xlrd.open_workbook, [filepath], {"formatting_info": False})
+
         # Specify the interface that shall be used
 
         opener, op_args, op_kwargs = type2opener[filetype]
@@ -355,7 +360,7 @@ class FileActions(Actions):
                     interface = Interface(self.grid.code_array, infile)
                     interface.to_code_array()
 
-                except ValueError, err:
+                except (ValueError, xlrd.biffh.XLRDError), err:
                     post_command_event(self.main_window, self.StatusBarMsg,
                                        text=str(err))
 
@@ -378,8 +383,9 @@ class FileActions(Actions):
                 # File sucessfully opened. Approve again to show status.
                 self.approve(filepath)
 
-        except IOError:
-            txt = _("Error opening file {filepath}.").format(filepath=filepath)
+        except IOError, err:
+            txt = _("Error opening file {filepath}:").format(filepath=filepath)
+            txt += " " + str(err)
             post_command_event(self.main_window, self.StatusBarMsg, text=txt)
 
             return False
@@ -597,7 +603,7 @@ class FileActions(Actions):
             self._move_tmp_file(tmpfilepath, filepath)
             self._release_save_states()
 
-        elif filetype == "pys":
+        elif filetype == "pys" or filetype == "all":
             self._set_save_states()
             if self._save_pys(tmpfilepath):
                 # Writing was successful
@@ -1409,7 +1415,7 @@ class SelectionActions(Actions):
                 for col in xrange(col_slc.start, col_slc.stop, col_slc.step):
                     self.select_cell(row, col, add_to_selected=True)
 
-    def delete_selection(self, selection=None):
+    def delete_selection(self, selection=None, mark_unredo=True):
         """Deletes selection, marks content as changed
 
         If selection is None then the current grid selection is used.
@@ -1419,6 +1425,8 @@ class SelectionActions(Actions):
 
         selection: Selection, defaults to None
         \tSelection that shall be deleted
+        mark_unredo: Boolean, defaults to True
+        \tIf True deletion is marked as separate undo step
 
         """
 
@@ -1436,7 +1444,8 @@ class SelectionActions(Actions):
                 self.grid.actions.delete_cell((row, col, tab),
                                               mark_unredo=False)
 
-        self.grid.code_array.unredo.mark()
+        if mark_unredo:
+            self.grid.code_array.unredo.mark()
 
         self.grid.code_array.result_cache.clear()
 
