@@ -1171,7 +1171,7 @@ class AboutDialog(object):
         info.Translators = ["Joe Hansen", "Mark Haanen", "Yuri Chornoivan",
                             u"Mario Blättermann", "Christian Kirbach",
                             "Martin Manns", "Andreas Noteng",
-                            "Enrico Nicoletto"]
+                            "Enrico Nicoletto", u"Frédéric Marchal"]
 
         license_file = open(get_program_path() + "/COPYING", "r")
         license_text = license_file.read()
@@ -1287,7 +1287,7 @@ class PreferencesDialog(wx.Dialog):
             "prepocessor": int,
         }),
         ("gpg_key_fingerprint", {
-            "label": _(u"GPG key id"),
+            "label": _(u"GPG fingerprint"),
             "tooltip": _(u"Fingerprint of the GPG key for signing files"),
             "widget": wx.TextCtrl,
             "widget_params": {},
