@@ -30,8 +30,18 @@ Unit tests for xls.py
 
 import os
 import sys
-import xlrd
-import xlwt
+
+try:
+    import xlrd
+except ImportError:
+    xlrd = None
+
+try:
+    import xlwt
+except ImportError:
+    xlwt = None
+
+import pytest
 
 import wx
 app = wx.App()
@@ -47,7 +57,7 @@ from src.lib.testlib import params, pytest_generate_tests
 from src.model.model import CodeArray
 from src.sysvars import get_dpi, get_default_font
 
-
+@pytest.mark.skipif(xlrd is None, reason="requires xlrd")
 class TestXls(object):
     """Unit tests for Xls"""
 
@@ -118,6 +128,7 @@ class TestXls(object):
     ]
 
     @params(param_shape2xls)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_shape2xls(self, tabs, res):
         """Test _shape2xls method"""
 
@@ -141,6 +152,7 @@ class TestXls(object):
     ]
 
     @params(param_code2xls)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_code2xls(self, key, val, code):
         """Test _code2xls method"""
 
@@ -186,6 +198,7 @@ class TestXls(object):
     ]
 
     @params(param_get_font)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_get_font(self, pointsize, fontweight, fontstyle, easyxf):
         """Test _get_font method"""
 
@@ -215,6 +228,7 @@ class TestXls(object):
     ]
 
     @params(param_get_alignment)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_get_alignment(self, justification, vertical_align, angle, easyxf):
         """Test _get_alignment method"""
 
@@ -241,6 +255,7 @@ class TestXls(object):
     ]
 
     @params(param_get_pattern)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_get_pattern(self, bgcolor, easyxf):
         """Test _get_pattern method"""
 
@@ -267,6 +282,7 @@ class TestXls(object):
     ]
 
     @params(param_get_borders)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_get_borders(self, borderwidth_right, borderwidth_bottom,
                          bordercolor_right, bordercolor_bottom, easyxf):
         """Test _get_borders method"""
@@ -298,6 +314,7 @@ class TestXls(object):
     ]
 
     @params(param_get_xfstyle)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_get_xfstyle(self, key, sec_key, subsec_key, style_key, val,
                          easyxf):
         """Test _get_xfstyle method"""
@@ -339,7 +356,7 @@ class TestXls(object):
         self.xls_in._xls2attributes(worksheet, 0)
 
         attrs = self.code_array.dict_grid.cell_attributes[key]
-        print attrs
+
         assert attrs[attr] == val
 #
 #    param_cell_attribute_append = [
@@ -380,6 +397,7 @@ class TestXls(object):
     ]
 
     @params(param_row_heights2xls)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_row_heights2xls(self, row, tab, hpixels):
         """Test _row_heights2xls method"""
 
@@ -401,8 +419,8 @@ class TestXls(object):
         assert worksheet.rowinfo_map[row].height == int(xlsheight)
 
     param_xls2row_heights = [
-        {'row': 1, 'tab': 0, 'height': 44.500},
-        {'row': 10, 'tab': 0, 'height': 45.511},
+        {'row': 1, 'tab': 0, 'height': 44},
+        {'row': 10, 'tab': 0, 'height': 45},
     ]
 
     @params(param_xls2row_heights)
@@ -415,7 +433,7 @@ class TestXls(object):
 
         self.xls_in._xls2row_heights(worksheet, tab)
         res = self.code_array.dict_grid.row_heights[(row, tab)]
-        assert round(res, 3) == height
+        assert int(res) == height
 
     param_col_widths2xls = [
         {'col': 0, 'tab': 0, 'width': 0.1, 'points': 3},
@@ -426,6 +444,7 @@ class TestXls(object):
     ]
 
     @params(param_col_widths2xls)
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_col_widths2xls(self, col, tab, width, points):
         """Test _col_widths2xls method"""
 
@@ -460,6 +479,7 @@ class TestXls(object):
         res = self.code_array.dict_grid.col_widths[(col, tab)]
         assert round(res, 3) == width
 
+    @pytest.mark.skipif(xlwt is None, reason="requires xlwt")
     def test_from_code_array(self):
         """Test from_code_array method"""
 
